function TheRadius = maximum_radius_for_oblateness_and_tilt(Oblateness, AxialTilt)

    % Obtain the maximum radius for this oblateness and tilt angle as follows

    % Generate the angles for a 1/4 segment of the ellipse
    EllipseAngles = [0:90] * unitsratio('rad', 'deg');

    % And the radius for each angle
    Radii = Oblateness ./ sqrt((Oblateness .^ 2 * cos(EllipseAngles) .^ 2) + (sin(EllipseAngles) .^ 2));

    % Now tilt the ellipse by the axial tilt
    TiltedAngles = EllipseAngles + (AxialTilt * unitsratio('rad', 'deg'));

    % And turn the polar coordinates into cartesian
    [x_e, y_e] = pol2cart(TiltedAngles, Radii);

    % Get the maximum y value and its index
    [max_r, max_r_index] = max(y_e);

    % That then lets us pull out the maximum radius
    TheRadius = Radii(max_r_index);

end