% Create a figure to plot onto
fig = figure;

% Define the sphere we want to plot onto
[x y z] = sphere(360);
    % divides the sphere into 1 degree sections

% Define how oblate this sphere(oid) is; 1 is spherical; less than one makes it 
% oblate (flattened); more than one makes it prolate (elongated); see
% http://en.wikipedia.org/wiki/Spheroid.
Oblateness = 0.763;

% Now adjust the z data to account for the oblateness
z = z .* Oblateness;

% % Read in the image data, including its colourmap
I = imread('H:\Personal\Aliens_5\tt_ff_image.jpg');

[I2, map] = rgb2ind(I, 256);

% Generate a surface plot of the sphere we've created, coloured with the
% image we've just read in (which forms a texture map); flipud is necessary
% to get the output world to be the right way up!
SurfHandle = ...
    surface(x, y, z,                    ...
            'FaceColor',    'texture',  ...
            'EdgeColor',    'none',     ...
            'CDataMapping', 'direct',   ...
            'Cdata',        flipud(I2)  ...
            );

hold on

% -----------------------------------------
% Set the axial tilt for the world
AxialTilt = 28;

% -----------------------------------------
% Equalise the three axes so it appears as a sphere
axis equal;

% Set the colour map to be that of the image, so it is actually coloured
% the same as the original image
colormap(map);

% Turn off the axes so it's just a sphere on a blank background
axis off;

% Set the axis limits to the range of the data.
% axis tight;

% Freeze aspect ratio properties to enable rotation of 3-D objects and
% override stretch-to-fill
axis vis3d;

% Set the axis limits and PlotBoxAspectRatio so that the axes fill the
% position rectangle
axis fill;

% Set the figure position and size to be what we want
figposn = get(fig, 'Position');
set(fig, 'Position', [figposn(1) figposn(2) 440 440]);

% And the size of the axes within the figure
set(gca, 'Position', [0.05 0.05 0.9 0.9]);
    % This is relative to the size of the figure by default, so 0 is the
    % extreme left/bottom and 1 the extreme right/top...

% Set the background to be black
set(gcf, 'Color', 'black');

% Ensure that the black background prints out (saves)
set(gcf, 'InvertHardcopy', 'off');

% Ensure pixels along the edge are lit correctly
set(SurfHandle, 'BackFaceLighting',         'lit');

% And that the reflectance is correct
set(SurfHandle, 'SpecularColorReflectance', 0);

% -----------------------------------------
% Now draw the rings around the world, from various angles and lighting
% positions
% draw_rings_and_shadow(45, 45, Oblateness, AxialTilt, '1', x(z == 0), y(z == 0));
% draw_rings_and_shadow(60, 45, Oblateness, AxialTilt, '2', x(z == 0), y(z == 0));
% draw_rings_and_shadow(80, 45, Oblateness, AxialTilt, '3', x(z == 0), y(z == 0));
draw_rings_and_shadow(80, 0,  Oblateness, AxialTilt, '4', x(z == 0), y(z == 0));

%=========================================================================

close all;
